@@ -23,9 +23,8 @@ const char* const gl_error_symbol_strings[] = {
 };
 
 int is_gl_error(int rval) {
-    int err;
-    err = rval & 0x0507 > 0 ? (rval & 0x07) + 1 : 0;
-    return err;
+    if (!(rval & 0x0507)) return 0;
+    return (rval & 0x07) + 1;
 }
 
 const char* gl_error_string(int err) {
